{{ self.title() }}

作者，版权声明等

## 题目简述

可以把题目的要点再说一遍。

## 子任务设计

如果有的话，也许需要解释一下部分分都是怎么设计的。

## 算法1：暴力

列举一下常见的不推荐写法：

| 不推荐写法          | 推荐写法                                    | 解释                                       |
| -------------- | --------------------------------------- | ---------------------------------------- |
| $O(n^3)$       | $O\left(n^3 \right)$                    | 长得比较高的括号里的东西，要告诉括号把高出来的部分括进去             |
| $log(n)$       | $\log{n}$                               | `log` 是有专门的正体符号，不要用斜体的变量格式               |
| $max$          | $\max$                                  | 同上                                       |
| $a~mod~Q$      | $a\bmod Q$                              | 我们常用的 `mod` 是 `\bmod`                    |
| $O(n*m/32)$    | $O\left(\frac{nm}{w}\right)$，其中 $w$ 是字长 | 大O的常数是忽略的，没有意义；这么写容易误导人在O里面写常数；星号不是乘号，可以不写或用 `\times` 或 `\cdot` |
| 第k(k<j)个       | 第 $k$（$k<j$）个                           | 数学表达式应当用表达式，行文中的标点符号（这里是表解释的圆括号）要统一用中文标点（也可以像数学书上统一用英文标点） |
| $d[a[i][b[j]]$ | $d\left(a_i, b_j\right)$                | 方括号表下标比较少见，一般用圆括号和下标                     |
| $a~xor~b$      | $a~\mathrm{xor}~b$                      | 不存在的算符可以用 `\mathrm{}` 造出来                |
| 输出“Yes”（不包含引号） | 输出 `Yes`                                | 字符串有专门的格式可以用，不用使用引号加正文                   |

